<?php
	/***************
	 * create.php
	 * Creates the database we will be using for this example.
	 * This is the only example that will use inline PDO code
	 * 
	 * Jaime Ruiz 		initial		March 2, 2015
	 */
	require_once "inc/page_setup.php";
	
	
	//Set some variables required by header
	$title = "Databases with PDO and SQLite";
	$page_name ="create";
	//Include example header
	include 'inc/header.php';
	
?>
<main>
	<div class="container">
		<div class="row">
			<div class="col-sm-3">
				<?php 
					include "inc/sidenav.php";
				?>
			</div>
			<div class="col-sm-9">
			In this page we demonstrate how to initialize a database.  There
			is a lot going on there.
			
			<ol>
				<li>Start a connection
					<?php 
						try {
							$dbh = new PDO("sqlite:./music2.db");
							echo '<pre class="bg-success">';
							echo 'Connection successful.';
							echo '</pre>';
						} catch (PDOException $e) {
							/* If you get here it is mostly a permissions issue
							 * or that your path to the database is wrong
							 */
							echo '<pre class="bg-danger">';
							echo 'Connection failed: ' . $e->getMessage();
	 						echo '</pre>';
	 						die;
						}
					?>
				</li>
				<li>Delete old tables. Here we want to use exec() because the 
					drop command does not return a queryset but instead number of
					rows effected. (Note: Always returns 0 when deleting or creating
					tables.)
					<p>Delete artist:</p>
					<?php 
						/* 
						 * This will only delete the table if it actually exists
						 */
						$sql = "DROP TABLE IF EXISTS artist";
						$status = $dbh->exec($sql);
						if($status === FALSE){
							echo '<pre class="bg-danger">';
							/*
							 * Fetch extended error information associated with
							 *  the last operation on the database handle
							 */
							print_r($dbh->errorInfo());
							echo '</pre>';
						}else{
							echo '<pre class="bg-success">';
							echo 'Number of rows effected: ' . $status;
							echo '</pre>';
						}
					?>
					<p>Delete albums:</p>
					<?php 
						/* 
						 * This will only delete the table if it actually exists
						 */
						$sql = "DROP TABLE IF EXISTS album";
						$status = $dbh->exec($sql);
						if($status === FALSE){
							echo '<pre class="bg-danger">';
							print_r($dbh->errorInfo());
							echo '</pre>';
						}else{
							echo '<pre class="bg-success">';
							echo 'Number of rows effected: ' . $status;
							echo '</pre>';
						}
					?>
				</li>
				<li>Create Tables. The SQL here is the same as if you were
					doing it via command line
					<p>Artist Table</p>
					<?php 
						$sql = "CREATE TABLE artist (artist_id INTEGER PRIMARY KEY ASC, artist_name varchar(50))";
						$status = $dbh->exec($sql);
						if($status === FALSE){
							echo '<pre class="bg-danger">';
							print_r($dbh->errorInfo());
							echo '</pre>';
						}else{
							echo '<pre class="bg-success">';
							echo 'Number of rows effected: ' . $status;
							echo '</pre>';
						}
					?>
					<p>Albums Table</p>
					<?php 
						$sql = "CREATE TABLE album (album_id INTEGER PRIMARY KEY ASC, artist_id int(5), title varchar(255), year int(4), rank int(5))";
						$status = $dbh->exec($sql);
						if($status === FALSE){
							echo '<pre class="bg-danger">';
							print_r($dbh->errorInfo());
							echo '</pre>';
						}else{
							echo '<pre class="bg-success">';
							echo 'Number of rows effected: ' . $status;
							echo '</pre>';
						}
					?>
					</li>
					<li>Load Values Into Database
					<?php 
						/*This include is a function that will load from a csv and
						 * return the albums for us. Doing it like this because
						 * we only use it for this file.
						 */
						require "source_file/list.php";
						$albums = getAlbumsFromFile();
						$artists_ids = array(); //Going to use to store artists as we add them
						$sql_artist = "INSERT INTO artist (artist_name) VALUES (?)";
						$sql_album = "INSERT INTO album (artist_id, title, year, rank)
									 VALUES (:artist_id, :title, :year, :rank)";
						//This allows caching of statements and optimized queries
						$artist_stm = $dbh->prepare($sql_artist);
						$album_stm = $dbh->prepare($sql_album);
						foreach ($albums as $current_album){
							//1. Check to make sure artist hasn't already been added
							if( key_exists($current_album['Band'], $artists_ids)){
								$artist_id = $artists_ids[$current_album['Band']];
							}else{
								if(!$artist_stm->execute(array($current_album['Band']))){
									echo '<pre class="bg-danger">';
									print_r($dbh->errorInfo());
									echo '</pre>';
								}
								$artist_id = $dbh->lastInsertId('artist_id');
								$artists_ids[$current_album['Band']] = $artist_id;
							}
							if(!$album_stm->execute(
									array(
									':artist_id' => $artist_id,
									':title' => $current_album['Title'],
									':year' => $current_album['Year'],
									':rank' => $current_album['Rank'])
									)
								){
								echo '<pre class="bg-danger">';
								print_r($dbh->errorInfo());
								echo '</pre>';
							}
						}
					?>
					</li>
					<li>Check Values (should be 100 albums but less artist since The Beatles and Led Zepplin Rock.
					<p class="bg-success">
					<?php 
						$artist_num = $dbh->query("SELECT count(*) FROM artist");
						$album_num = $dbh->query("SELECT count(*)  FROM album");
						echo "Number of artists: " . $artist_num->fetchColumn() . '<br />'; //Don't need to specify because only 1 col is returned
						echo "Number of albums: " . $album_num->fetchColumn() . '';
					?>
					</p>
					</li>
			</ol>
			
			
			 
			   
			</div>
		</div>
	</div>
</main>

<?php include 'inc/footer.php'; ?>
